.. _examples:

========
Examples
========

The examples source code can be found in the repository `examples` folder. These notebooks should give you a basic idea on how to use some of the most important features of SAM.

See:

* `Feature engineering example <https://github.com/RoyalHaskoningDHV/sam/blob/main/examples/feature_engineering.ipynb>`_
* `Simple model example <https://github.com/RoyalHaskoningDHV/sam/blob/main/examples/mlp.ipynb>`_
